@@ -275,6 +275,9 @@ Device::~Device()
 
 Device & Device::operator=(const Device &other)
 {
+	if(this == &other)
+		return *this;
+
 	if(d)
 	{
 		if(other.d)
@@ -785,6 +788,7 @@ public:
 		if(c)
 		{
 			c->qobject()->disconnect(this);
+			c->qobject()->setParent(0);
 			enabled = false;
 			c = 0;
 		}
@@ -793,6 +797,7 @@ public:
 			return;
 
 		c = _c;
+		c->qobject()->setParent(this);
 		connect(c->qobject(), SIGNAL(readyRead()), SLOT(c_readyRead()));
 		connect(c->qobject(), SIGNAL(packetsWritten(int)), SLOT(c_packetsWritten(int)));
 		connect(c->qobject(), SIGNAL(destroyed()), SLOT(c_destroyed()));
